==> order-center-domain-3.0.0-CLOUD-DEV-20250916.095233-183-sources.jar: com/tydic/dyc/oc/model/saleorder/sub/UocSaleOrderPayConf.java <==
package com.tydic.dyc.oc.model.saleorder.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题:UocSaleOrderPayConf
 * 说明:销售单支付配置
 * 时间:2022-02-21 19:11
 * 作者:罗有
 **/
@Data
public class UocSaleOrderPayConf implements Serializable {
	private static final long serialVersionUID =  -638231126442954506L;

	@DocField(value = "id")
	private Long id;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "销售单id")
	private Long saleOrderId;

	@DocField(value = "付款方式 0 预付款按比例支付,1 按协议约束支付,2 按账期支付")
	private Integer payType;

	@DocField(value = "付款方式翻译")
	private String payTypeStr;

	@DocField(value = "预付款(比例)")
	private BigDecimal prePaySup;

	@DocField(value = "到货款(比例)")
	private BigDecimal verPaySup;

	@DocField(value = "验收款(比例)")
	private BigDecimal pilPaySup;

	@DocField(value = "质保金(比例)")
	private BigDecimal quaPaySup;

	@DocField(value = "预付款")
	private BigDecimal prePayFee;

	@DocField(value = "到货款")
	private BigDecimal verPayFee;

	@DocField(value = "验收款")
	private BigDecimal pilPayFee;

	@DocField(value = "质保金")
	private BigDecimal quaPayFee;

	@DocField(value = "预付款-已付")
	private BigDecimal prePayedFee;

	@DocField(value = "到货款-已付")
	private BigDecimal verPayedFee;

	@DocField(value = "验收款-已付")
	private BigDecimal pilPayedFee;

	@DocField(value = "质保金-已付")
	private BigDecimal quaPayedFee;

	@DocField(value = "账期天数")
	private Integer paymentDays;

	@DocField(value = "指定账期日")
	private Integer payAccountDay;

	@DocField(value = "使用类型：1：采购方；2：平台方")
	private Integer userType;

	@DocField(value = "使用类型翻译")
	private String userTypeStr;

	@DocField(value = "账期支付结算规则 1:指定账期日 2:账期起算特定业务节点+账期天数")
	private Integer payRule;

	@DocField(value = "账期支付结算规则翻译")
	private String payRuleStr;

	@DocField(value = "违约金额比例")
	private BigDecimal payBreakScale;

	@DocField(value = "账期日结算订单规则 1:签收发票开始 2:订单验收 3:订单到货")
	private Integer payAccountDayRule;

	@DocField(value = "账期起算特定业务节点 1:签收发票开始计算 2:订单验收开始计算 3:订单到货开始计算")
	private Integer payNodeRule;

	@DocField(value = "账期日结算订单规则翻译")
	private String payAccountDayRuleStr;

	@DocField(value = "账期起算特定业务节点翻译")
	private String payNodeRuleStr;

	@DocField(value = "合同ID")
	private String modelContractId;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	/**
	 * 租户id
	 */
	private Long sysTenantId;
	/**
	 * 租户名称
	 */
	private String sysTenantName;

}

==> order-center-domain-3.1.0-CLOUD-DEV-20230625.084845-58-sources.jar: com/tydic/dyc/oc/model/saleorder/sub/UocSaleOrderPayConf.java <==
package com.tydic.dyc.oc.model.saleorder.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题:UocSaleOrderPayConf
 * 说明:销售单支付配置
 * 时间:2022-02-21 19:11
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocSaleOrderPayConf implements Serializable {
	private static final long serialVersionUID =  -638231126442954506L;

	@DocField(value = "id")
	private Long id;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "销售单id")
	private Long saleOrderId;

	@DocField(value = "付款方式 0 预付款按比例支付,1 按协议约束支付,2 按账期支付")
	private Integer payType;

	@DocField(value = "付款方式翻译")
	private String payTypeStr;

	@DocField(value = "预付款(比例)")
	private BigDecimal prePaySup;

	@DocField(value = "到货款(比例)")
	private BigDecimal verPaySup;

	@DocField(value = "验收款(比例)")
	private BigDecimal pilPaySup;

	@DocField(value = "质保金(比例)")
	private BigDecimal quaPaySup;

	@DocField(value = "预付款")
	private BigDecimal prePayFee;

	@DocField(value = "到货款")
	private BigDecimal verPayFee;

	@DocField(value = "验收款")
	private BigDecimal pilPayFee;

	@DocField(value = "质保金")
	private BigDecimal quaPayFee;

	@DocField(value = "预付款-已付")
	private BigDecimal prePayedFee;

	@DocField(value = "到货款-已付")
	private BigDecimal verPayedFee;

	@DocField(value = "验收款-已付")
	private BigDecimal pilPayedFee;

	@DocField(value = "质保金-已付")
	private BigDecimal quaPayedFee;

	@DocField(value = "账期天数")
	private Integer paymentDays;

	@DocField(value = "指定账期日")
	private Integer payAccountDay;

	@DocField(value = "使用类型：1：采购方；2：平台方")
	private Integer userType;

	@DocField(value = "使用类型翻译")
	private String userTypeStr;

	@DocField(value = "账期支付结算规则 1:指定账期日 2:账期起算特定业务节点+账期天数")
	private Integer payRule;

	@DocField(value = "账期支付结算规则翻译")
	private String payRuleStr;

	@DocField(value = "违约金额比例")
	private BigDecimal payBreakScale;

	@DocField(value = "账期日结算订单规则 1:签收发票开始 2:订单验收 3:订单到货")
	private Integer payAccountDayRule;

	@DocField(value = "账期起算特定业务节点 1:签收发票开始计算 2:订单验收开始计算 3:订单到货开始计算")
	private Integer payNodeRule;

	@DocField(value = "账期日结算订单规则翻译")
	private String payAccountDayRuleStr;

	@DocField(value = "账期起算特定业务节点翻译")
	private String payNodeRuleStr;

	@DocField(value = "合同ID")
	private String modelContractId;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;



}
